@@ -16,5 +16,9 @@ sys.modules['PreferencePanes'] = mod = objc.ObjCLazyModule('PreferencePanes',
     _metadata.__dict__, None, {
        '__doc__': __doc__,
        '__path__': __path__,
+       '__loader__': globals().get('__loader__', None),
        'objc': objc,
     }, ( AppKit,))
+
+import sys
+del sys.modules['PreferencePanes._metadata']
